@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use Perl::Critic::Utils;
 use PPIx::Utils::Traversal qw(get_constant_name_elements_from_declaring_statement);
+use Scalar::Util qw(refaddr);
 use parent 'Perl::Critic::Policy';
 
 sub default_themes       { return qw( maintenance )     }
@@ -22,18 +23,19 @@ sub violates {
         next unless $st->schild(0) eq 'use' && $st->module eq 'constant';
         my @constants = get_constant_name_elements_from_declaring_statement( $st );
         for my $tok (@constants) {
-            push @{ $defined_constants{"$tok"} }, $tok;
+            push @{ $defined_constants{"$tok"} }, $st;
         }
     }
 
     for my $el_word (@{ $elem->find( sub { $_[1]->isa('PPI::Token::Word') }) ||[]}) {
-        my $st = $el_word;
-        while ($st) {
-            last if ($st->isa('PPI::Statement::Include'));
-            $st = $st->parent;
+        my $st = $el_word->statement;
+        if ($defined_constants{"$el_word"}) {
+            for my $st (@{ $defined_constants{"$el_word"} }) {
+                unless ($el_word->descendant_of($st)) {
+                    $used{"$el_word"}++;
+                }
+            }
         }
-        next if $st;
-        $used{"$el_word"}++;
     }
 
     my @violations;
